.. _decorator:

dooku.decorator
===============

Decorator is a part of Dooku that contains various useful decorators that
could be helpful in daily usage basis. The module is very small now, so
please feel free to contribute and share your experience with others.


cached_property
---------------

.. autoclass:: dooku.decorator.cached_property
